/* This is an example for the HC-SR04 distance sensor.  
   For this example to work, connect the "Trig"-pin from 
   the sensor to pin 12 of the Arduino and connect 
   "Echo"-pin from the sensor to pin 11 of the Arduino
*/

/* include libraries */
#include <NewPing.h>

/* define pins and other constant values */
#define TRIGGER_PIN  12  // Arduino pin tied to trigger pin on the ultrasonic sensor.
#define ECHO_PIN     11  // Arduino pin tied to echo pin on the ultrasonic sensor.
#define MAX_DISTANCE 200 // Maximum distance we want to ping for (in centimeters). Maximum sensor distance is rated at 400-500cm.

/* declare globale variables */
NewPing sonar(TRIGGER_PIN, ECHO_PIN, MAX_DISTANCE); // NewPing setup of pins and maximum distance.

/* This function is run only once at the startup of the arduino */
void setup() {
  Serial.begin(9600); // Start serial to send information from arduino to computer
}

/* This funtion is repeated until the arduino is shuts off */
void loop() {
  delay(50);                     
  int distance = getDistance();
  Serial.print("Distance: ");
  Serial.print(distance);
  Serial.println("cm");
}

/* This function reads the distance from sensor */
int getDistance() {
  unsigned int uS = sonar.ping(); // Send ping, get ping time in microseconds (uS).
  int value = (int) (uS / US_ROUNDTRIP_CM);
  if(value == 0) value = MAX_DISTANCE;
  return value;
}
